@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.528";
+our $VERSION = "0.529";
 
 1;
 
@@ -318,10 +318,12 @@ Exceptions thrown by L<Sys::IO#flock|SPVM::Sys::IO/"flock"> method could be thro
 
 =head2 mkdir
 
-C<static method mkdir : void ($dir : string, $mode : int);>
+C<static method mkdir : void ($dir : string, $mode : int = -1);>
 
 Creates the directory given the path $dir and the mode $mode.
 
+If $mode is less than 0, $mode is set to 0777.
+
 The permissions of the created directory are ($mode & ~L<umask|/"umask"> & 0777).
 
 In Windows, the mode $mode is ignored.
@@ -1631,6 +1633,32 @@ C<static method getgrnam : L<Sys::User::Group|SPVM::Sys::User::Group> ($name : s
 
 Searches a group entry given The group name $name. If found, returns the group entry, otherwise return undef.
 
+=head2 srand
+
+C<static method srand : void ($seed : int);>
+
+Sets the random number $seed for L</"rand"> method.
+
+Implementation:
+
+Calls L<Fn#set_seed|SPVM::Fn/"set_seed"> method given $seed.
+
+=head2 rand
+
+C<static method rand : double ($max : int = 1);>
+
+Returns a random fractional number greater than or equal to 0 and less than $max.
+
+If C<seed> stack variable is initialized, the random seed is got from the variable.
+
+Otherwise the random seed is created from the process ID and epoch time.
+
+The reference of the seed is passed to L<Fn#crand|SPVM::Fn|/"crand"> method.
+
+The returned seed is passed to L</"srand"> method to update C<seed> stack variable.
+
+If you change the random seed before calling this method, you can use L</"srand"> method.
+
 =head1 Modules
 
 =over 2
